@@ -10,6 +10,7 @@ import importlib
 import logging
 
 from calcure.calendars import Calendar
+from calcure.errors import error
 from calcure.configuration import cf
 from calcure.weather import Weather
 from calcure.importers import Importer
@@ -39,7 +40,7 @@ else:
     from calcure.translations.en import *
 
 
-__version__ = "2.8.3"
+__version__ = "2.8.5"
 
 
 def read_items_from_user_arguments(screen, user_tasks, user_events, task_saver_csv, event_saver_csv):
@@ -89,7 +90,13 @@ class View:
             return
 
         # Cut the text if it does not fit the screen:
-        text = text[:(x_max - 1 - x)]
+        real_text = text.replace('\u0336', "")
+        number_of_characters = len(real_text)
+        available_space = x_max - x
+        number_of_special = text.count('\u0336')
+        if number_of_characters > available_space:
+            coefficient = 2 if number_of_special > 0 else 1
+            text = f"{text[:(available_space - 1)*coefficient]}"
 
         if bold and underlined:
             self.stdscr.addstr(y, x, text, curses.color_pair(color.value) | curses.A_BOLD | curses.A_UNDERLINE)
@@ -108,7 +115,6 @@ class TaskView(View):
         super().__init__(stdscr, y, x)
         self.task = task
         self.screen = screen
-        self.info = f'{self.icon} {self.task.name[self.indent:]}'
 
     @property
     def color(self):
@@ -144,14 +150,19 @@ class TaskView(View):
             return 2
         return 0
 
-    def obfuscate_info(self):
-        """Obfuscate the info if privacy mode is on"""
-        self.info = f'{cf.TODO_ICON} {cf.PRIVACY_ICON * len(self.task.name[self.indent:])}'
+    @property
+    def info(self):
+        """Icon and name of the task, which is decorated if needed"""
+        name = self.task.name[self.indent:]
+        if self.screen.privacy or self.task.privacy:
+            return f'{cf.TODO_ICON} {cf.PRIVACY_ICON * len(name)}'
+        if self.task.status == Status.DONE and cf.STRIKETHROUGH_DONE_TASKS:
+            strike = "\u0336"
+            return f'{self.icon} {strike}{strike.join(name)}{strike}'
+        return f'{self.icon} {name}'
 
     def render(self):
         """Render a line with an icon, task, deadline, and timer"""
-        if self.screen.privacy or self.task.privacy:
-            self.obfuscate_info()
         self.display_line(self.y, self.x + self.indent, self.info, self.color)
 
         deadline_indentation = self.screen.x_min + 2 + len(self.info) + self.indent
@@ -399,55 +410,55 @@ class DailyView(View):
 
         # Show user events:
         for event in self.user_events.items:
-            if index < self.y_cell - 1:
+            if index >= self.y_cell - 1 and self.screen.calendar_state == CalState.MONTHLY:
+                self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.EVENTS)
+            else:
                 user_event_view = UserEventView(self.stdscr, self.y + index, self.x, event, self.screen)
                 user_event_view.render()
                 if self.screen.selection_mode and self.is_selection_day:
                     self.display_line(self.y + index, self.x, str(index + self.index_offset + 1), Color.ACTIVE_PANE)
-            else:
-                self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.EVENTS)
             index += 1
 
         # Show repeated user events and events from ics:
         for event_list in [self.repeated_user_events.items, self.user_ics_events.items]:
             for event in event_list:
-                if index < self.y_cell - 1:
+                if index >= self.y_cell - 1 and self.screen.calendar_state == CalState.MONTHLY:
+                    self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.EVENTS)
+                else:
                     user_event_view = UserEventView(self.stdscr, self.y + index, self.x, event, self.screen)
                     user_event_view.render()
-                else:
-                    self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.EVENTS)
                 index += 1
 
         # Show deadlines for tasks, both from csv and ics files:
         for deadline_list in [self.deadlines.items, self.deadlines_ics.items]:
             for event in deadline_list:
-                if index < self.y_cell - 1:
+                if index >= self.y_cell - 1 and self.screen.calendar_state == CalState.MONTHLY:
+                    self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.DEADLINES)
+                else:
                     deadline_view = DeadlineView(self.stdscr, self.y + index, self.x, event, self.screen)
                     deadline_view.render()
-                else:
-                    self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.DEADLINES)
                 index += 1
 
         # Show holidays:
         if not cf.DISPLAY_HOLIDAYS:
             return
         for event in self.holidays.items:
-            if index < self.y_cell - 1:
+            if index >= self.y_cell - 1 and self.screen.calendar_state == CalState.MONTHLY:
+                self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.HOLIDAYS)
+            else:
                 holiday_view = HolidayView(self.stdscr, self.y + index, self.x, event, self.screen)
                 holiday_view.render()
-            else:
-                self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.HOLIDAYS)
             index += 1
 
         # Show birthdays:
         if not cf.BIRTHDAYS_FROM_ABOOK:
             return
         for event in self.birthdays.items:
-            if index < self.y_cell - 1:
+            if index >= self.y_cell - 1 and self.screen.calendar_state == CalState.MONTHLY:
+                self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.BIRTHDAYS)
+            else:
                 birthday_view = BirthdayView(self.stdscr, self.y + index, self.x, event, self.screen)
                 birthday_view.render()
-            else:
-                self.display_line(self.y + self.y_cell - 2, self.x, self.hidden_events_sign, Color.BIRTHDAYS)
             index += 1
 
         self.num_events_this_day = index
@@ -546,6 +557,22 @@ class FooterView(View):
         self.display_line(self.screen.y_max - 1, 0, hint, Color.HINTS)
 
 
+class ErrorView(View):
+    """Display the error messages"""
+
+    def __init__(self, stdscr, y, x, screen):
+        super().__init__(stdscr, y, x)
+        self.screen = screen
+        self.error = error
+
+    def render(self):
+        """Render this view on the screen"""
+        if self.error.has_occured:
+            clear_line(self.stdscr, self.screen.y_max - 2)
+            self.display_line(self.screen.y_max - 2, 0, MSG_ERRORS, Color.IMPORTANT)
+            self.error.clear_buffer()
+
+
 class SeparatorView(View):
     """Display the separator in the split screen"""
 
@@ -955,6 +982,7 @@ def main(stdscr) -> None:
     welcome_screen_view = WelcomeScreenView(stdscr, 0, 0, screen)
     footer_view = FooterView(stdscr, 0, 0, screen)
     separator_view = SeparatorView(stdscr, 0, 0, screen)
+    error_view = ErrorView(stdscr, 0, 0, screen)
 
     # Show welcome screen on the first run:
     if cf.is_first_run:
@@ -982,7 +1010,8 @@ def main(stdscr) -> None:
             monthly_screen_view.render()
             if screen.split: separator_view.render()
             footer_view.render()
-            control_monthly_screen(stdscr, user_events, screen, importer)
+            error_view.render()
+            control_monthly_screen(stdscr, screen, user_events, importer)
 
         # Daily (active) screen:
         elif screen.state == AppState.CALENDAR and screen.calendar_state == CalState.DAILY:
@@ -994,7 +1023,8 @@ def main(stdscr) -> None:
             daily_screen_view.render()
             if screen.split: separator_view.render()
             footer_view.render()
-            control_daily_screen(stdscr, user_events, screen, importer)
+            error_view.render()
+            control_daily_screen(stdscr, screen, user_events, importer)
 
         # JOURNAL
 
@@ -1012,7 +1042,8 @@ def main(stdscr) -> None:
             journal_screen_view.render()
             if screen.split: separator_view.render()
             footer_view.render()
-            control_journal_screen(stdscr, user_tasks, screen, importer)
+            error_view.render()
+            control_journal_screen(stdscr, screen, user_tasks, importer)
 
         # Help screen:
         elif screen.state == AppState.HELP:
