@@ -118,6 +118,7 @@ class Config:
                 "underlined_weekend_names": "No",
                 "underlined_title":         "No",
                 "underlined_active_pane":   "No",
+                "strikethrough_done_tasks": "Yes",
                 }
 
         conf["Event icons"] = {
@@ -276,6 +277,7 @@ class Config:
             self.UNDERLINED_WEEKEND_NAMES = conf.getboolean("Styles", "underlined_weekend_names", fallback=False)
             self.UNDERLINED_TITLE         = conf.getboolean("Styles", "underlined_title", fallback=False)
             self.UNDERLINED_ACTIVE_PANE   = conf.getboolean("Styles", "underlined_active_pane", fallback=False)
+            self.STRIKETHROUGH_DONE_TASKS = conf.getboolean("Styles", "strikethrough_done_tasks", fallback=True)
 
             # Icons:
             self.TODAY_ICON       = conf.get("Parameters", "today_icon", fallback="•") if self.DISPLAY_ICONS else "·"
@@ -337,24 +339,18 @@ class Config:
                     print ('Calcure - version 2.8.2')
                 elif opt in ('-i'):
                     self.USE_PERSIAN_CALENDAR = True
-        except getopt.GetoptError:
-            logging.error("Invalid user arguments")
+        except getopt.GetoptError as e_message:
+            logging.error("Invalid user arguments. %s", e_message)
             pass
 
 
+# Initialise config:
 cf = Config()
 
 # Create config folder:
 if not os.path.exists(cf.config_folder):
     os.makedirs(cf.config_folder)
 
-# Start logging:
-logging.basicConfig(level=logging.INFO,
-                    format="[%(levelname)s] %(message)s",
-                    encoding='utf-8',
-                    handlers=[logging.FileHandler(f"{cf.config_folder}/info.log", 'w'),
-                              logging.StreamHandler()],)
-
 # Read config file:
 cf.create_config_file()
 cf.read_config_file_from_user_arguments()
